@@ -35,7 +35,7 @@ class MailMerge(object):
 
         to_delete = []
 
-        r = re.compile(r' MERGEFIELD "?([^ ]+?)"? (| \\\* MERGEFORMAT )', re.I)
+        r = re.compile(r' MERGEFIELD +"?([^ ]+?)"? +(|\\\* MERGEFORMAT )', re.I)
         for part in self.parts.values():
             # Remove attribute that soft-links to other namespaces; other namespaces
             # are not used, so would cause word to throw an error.
@@ -98,13 +98,47 @@ class MailMerge(object):
                 fields.add(mf.attrib['name'])
         return fields
 
+    def merge_pages(self, replacements):
+        """
+        Duplicate template page. Creates a copy of the template for each item
+        in the list, does a merge, and separates the them by page breaks.
+        """
+        for part in self.parts.values():
+            root = part.getroot()
+
+            tag = root.tag
+            if tag == '{%(w)s}ftr' % NAMESPACES or tag == '{%(w)s}hdr' % NAMESPACES:
+                continue
+
+            children = []
+            for child in root:
+                root.remove(child)
+                children.append(child)
+
+            for i, repl in enumerate(replacements):
+                # Add page break in between replacements
+                if i > 0:
+                    pagebreak = ElementTree.Element('{%(w)s}br' % NAMESPACES)
+                    pagebreak.attrib['{%(w)s}type' % NAMESPACES] = 'page'
+                    root.append(pagebreak)
+
+                parts = []
+                for child in children:
+                    child_copy = deepcopy(child)
+                    root.append(child_copy)
+                    parts.append(child_copy)
+                self.merge(parts, **repl)
+
     def merge(self, parts=None, **replacements):
         if not parts:
             parts = self.parts.values()
 
         for part in parts:
-            for field, text in replacements.items():
-                self.__merge_field(part, field, text)
+            for field, replacement in replacements.items():
+                if isinstance(replacement, list):
+                    self.merge_rows(field, replacement)
+                else:
+                    self.__merge_field(part, field, replacement)
 
     def __merge_field(self, part, field, text):
         for mf in part.findall('.//MergeField[@name="%s"]' % field):
